@@ -215,8 +215,8 @@ class FiltersRequestListing(object):
                 'alliance': request.alliance,
                 'ship': request.ship_type,
                 'status': request.status.name,
-                'payout': int(payout),
-                'payout_str': str(payout),
+                'payout': payout.currency(commas=False),
+                'payout_str': payout.currency(),
                 'kill_timestamp': request.kill_timestamp,
                 'submit_timestamp': request.timestamp,
                 'division': request.division.name,
